@@ -76,7 +76,7 @@ only convert features between a subset of formats.
 
 """
 
-__version__ = '2.0.1'
+__version__ = '2.0.3'
 
 from collections import OrderedDict
 import re
@@ -185,7 +185,7 @@ class Project(object):
         """:class:`dict` of global :class:`Lists <List>` by name."""
 
         self.thumbnail = None
-        """A screenshot of the project. May be displayed in project browser."""
+        """An :class:`Image` with a screenshot of the project."""
 
         self.tempo = 60
         """The tempo in BPM used for note blocks."""
@@ -237,6 +237,9 @@ class Project(object):
         Path can be a file-like object, in which case format is required.
         Otherwise, can guess the appropriate format from the extension.
 
+        If you pass a file-like object, you're responsible for closing the
+        file.
+
         :param path:   Path or file pointer.
         :param format: :attr:`KurtFileFormat.name` eg. ``"scratch14"``.
                        Overrides the extension.
@@ -245,7 +248,8 @@ class Project(object):
         :raises: :py:class:`ValueError` if the format doesn't exist.
 
         """
-        if isinstance(path, basestring):
+        path_was_string = isinstance(path, basestring)
+        if path_was_string:
             (folder, filename) = os.path.split(path)
             (name, extension) = os.path.splitext(filename)
             if format is None:
@@ -262,7 +266,8 @@ class Project(object):
             raise ValueError, "Unknown format %r" % format
 
         project = plugin.load(fp)
-        fp.close()
+        if path_was_string:
+            fp.close()
         project.convert(plugin)
         if isinstance(path, basestring):
             project.path = path
@@ -300,7 +305,7 @@ class Project(object):
 
         p.variables = dict((n, v.copy()) for (n, v) in self.variables.items())
         p.lists = dict((n, l.copy()) for (n, l) in self.lists.items())
-        p.thumbnail = self.thumbnail.copy() if self.thumbnail else None
+        p.thumbnail = self.thumbnail
         p.tempo = self.tempo
         p.notes = self.notes
         p.author = self.author
@@ -490,10 +495,14 @@ class Project(object):
 
         # workaround unsupported features
         for feature in kurt.plugin.Feature.FEATURES.values():
-            if feature not in self._plugin.features and feature.workaround:
+            if feature not in self._plugin.features:
                 for x in feature.workaround(self):
                     yield UnsupportedFeature(feature, x)
 
+        # normalize supported features
+        for feature in self._plugin.features:
+            feature.normalize(self)
+
     def get_broadcasts(self):
         def get_broadcasts(block):
             for (arg, insert) in zip(block.args, block.type.inserts):
@@ -1077,13 +1086,13 @@ class Color(object):
                 r = [int(x, 16) for x in split]
             (r, g, b) = r
 
-        self.r = r
+        self.r = int(r)
         """Red component, 0-255"""
 
-        self.g = g
+        self.g = int(g)
         """Green component, 0-255"""
 
-        self.b = b
+        self.b = int(b)
         """Blue component, 0-255"""
 
     @property
@@ -1327,6 +1336,10 @@ class Insert(object):
     def __ne__(self, other):
         return not self == other
 
+    def copy(self):
+        return Insert(self.shape, self.kind, self.default, self.name,
+                      self.unevaluated)
+
     def stringify(self, value=None, block_plugin=False):
         if value is None or (value is False and self.shape == "boolean"):
             value = self.default
